generate_address
================

Generate a new address and its corresponding private key.

Returns:
    - **tuple**: A tuple containing the private key and address.

Example usage:

.. code-block:: python

    private_key, address = eth_client.generate_address()